onError property

void Function(Object error, StackTrace stackTrace)? onError
final

Invoked when a callback throws during call.

When null, errors are reported to the current Zone instead. Either way the dispatch continues with the remaining callbacks.

Implementation

final void Function(Object error, StackTrace stackTrace)? onError;