call abstract method

Map<int, CallbackReturnType> call(
  1. CallbackInputType input
)

Call all registered callbacks with the given input.

All registered callbacks will receive the same input value. Returns a map keyed by opaque registration id, in dispatch order.

Implementations are expected to keep dispatching when a callback throws and to tolerate being mutated from inside a callback.

Implementation

Map<int, CallbackReturnType> call(CallbackInputType input);