unregister abstract method
Removes a previously registered callback.
After unregistering, the callback will no longer be invoked.
If the callback was not registered, this operation is a no-op.
Example:
final callback = (int n) => n * 2;
handler.register(callback);
handler.unregister(callback); // Removes the callback
Implementation
void unregister(
CallbackWithReturn<CallbackInputType, CallbackReturnType> callback);